@@ -1,5 +1,7 @@
 # https://rowannicholls.github.io/python/statistics/agreement/correlation_coefficients.html#lins-concordance-correlation-coefficient-ccc
 # Lin LIK (1989). “A concordance correlation coefficient to evaluate reproducibility”. Biometrics. 45 (1):255-268.
+import numpy as np
+import pandas as pd
 
 def concordance_correlation_coefficient(y_true, y_pred):
     """Concordance correlation coefficient."""
