@@ -125,7 +125,7 @@ f.savefig(f"3drivers/site_r2_compare_sort_dif_{time_type}_b.pdf", dpi = 600, for
 
 # ========================================================================================================================
 # drop rows with duplicated index
-df3 = df3[~df3.index.duplicated(keep='first')]
+df = df[~df.index.duplicated(keep='first')]
 df = df.loc[:,~df.columns.duplicated()]
 
 # ========================================================================================================================
@@ -471,4 +471,59 @@ axes[0].xaxis.set_major_formatter(myFmt)
 
 # ======================================================================================================================================================
 # count values
-geolocations['Countrycode'].value_counts()
\ No newline at end of file
+geolocations['Countrycode'].value_counts()
+
+
+
+# ======================================================================================================================================================
+#  blended transformation
+import matplotlib.transforms as transforms
+trans = transforms.blended_transform_factory(ax.transData, ax.transAxes)
+
+# ======================================================================================================================================================
+# convert axes / data transform  
+# https://stackoverflow.com/questions/62004022/convert-from-data-coordinates-to-axes-coordinates-in-matplotlib
+
+import matplotlib.pyplot as plt
+
+fig, ax = plt.subplots()
+# this is in data coordinates
+point = (1000, 1000)
+trans = ax.transData.transform(point)
+trans = ax.transAxes.inverted().transform(trans)
+print(ax.get_xlim(), trans)  
+
+ax.set_xlim(0, 2000)
+ax.set_ylim(0, 2000)
+trans = ax.transData.transform(point)
+trans = ax.transAxes.inverted().transform(trans)
+print(ax.get_xlim(), trans)
+
+# =======================================================================================================================
+# auto nrows and ncols
+acnt = len(df.columns) - 1
+nc = int(np.ceil(np.sqrt(acnt)))
+if nc*(nc-1) >= acnt:
+    nr = nc - 1
+else:
+    nr = nc
+
+fig, axes = setup_canvas(nr,nc, figsize = (5 * nc, 3 * nr))#, wspace = 0.2, hspace = 0.2)
+
+# =======================================================================================================================
+# interp nc to sites
+df = nc['o3'].interp(longitude = meta['longitude'].to_xarray(), latitude = meta['latitude'].to_xarray()).to_dataframe()
+
+# =======================================================================================================================
+# Smooth 2D array
+from scipy.ndimage.filters import gaussian_filter
+from scipy.ndimage import uniform_filter, convolve1d
+
+klen = 2
+kernel = np.ones(klen)
+
+arr2Df = arr2D
+arr2Df = convolve1d(arr2Df, kernel)
+arr2Df = convolve1d(arr2Df.T, kernel).T
+
+nc = nc.coarsen(longitude=2, boundary = 'pad').mean().coarsen(latitude=2, boundary = 'pad').mean()
\ No newline at end of file
